import Vue from 'vue';
import vuexAlong from './vuex-along';
import router from './router';
import store from './store';
const i18n = {};
const activator = {};
export default {
  name: 'vue',
  extensionPoints: {
    'vue.app': {},
    'vue.plugin': {},
    'vue.options': {},
    'vue.router': {},
    'vuex.module': {}
  },
  activator
};

activator.start = function (moduleConfig) {
  const application = moduleConfig.getApplication();
  vuexAlong.setKey(`${application.name}-${application.version}`);
  let configs = moduleConfig.getExtension('vuex.module');

  for (let key in configs) {
    store.registerModule(key, configs[key]);
  }

  configs = moduleConfig.getExtension('vue.plugin');

  for (let key in configs) {
    Vue.use(configs[key]);
  }

  const options = [];
  configs = moduleConfig.getExtension('vue.options');

  for (let key in configs) {
    options.push(configs[key]);
  }

  configs = moduleConfig.getExtension('vue.router');

  for (let key in configs) {
    if (key === '/') {
      router.addRoutes(configs[key]);
    }
  }

  const app = moduleConfig.getExtension('vue.app');
  const vueOptions = {
    router,
    store,
    i18n,
    mixins: options,
    render: h => h(app.component)
  };
  new Vue(vueOptions).$mount(app.el);
};